@@ -2,7 +2,9 @@
 from matplotlib.patches import Rectangle
 
 
-class UpdatingRect(Rectangle):
+class UpdatingRect(Rectangle):  # pragma: no cover
+    """This class is used for ``fractpy.models.NewtonFractal.zoom_plot()``."""
+
     def __call__(self, ax):
         self.set_bounds(*ax.viewLim.bounds)
-        ax.figure.canvas.draw_idle()
\ No newline at end of file
+        ax.figure.canvas.draw_idle()
